@@ -3,7 +3,7 @@ package Dancer2::Plugin::OAuth2::Server;
 use strict;
 use warnings;
 use 5.008_005;
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 use Dancer2::Plugin;
 use URI;
 use URI::QueryParam;
@@ -40,7 +40,7 @@ on_plugin_import {
 };
 
 register 'oauth_scopes' => sub {
-    my ($dsl, $scopes, $code_ref) = plugin_args(@_);
+    my ($dsl, $scopes, $code_ref) = @_;
 
     my $settings = plugin_setting;
 
@@ -53,7 +53,7 @@ register 'oauth_scopes' => sub {
             $dsl->status( 400 );
             return $dsl->to_json( { error => $res[1] } );
         } else {
-            $dsl->var( oauth_access_token => $res[0] );
+            $dsl->app->request->var( oauth_access_token => $res[0] );
             goto $code_ref;
         }
     }
@@ -465,7 +465,7 @@ Pierre Vigier E<lt>pierre.vigier@gmail.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2015- Pierre Vigier
+Copyright 2016- Pierre Vigier
 
 =head1 LICENSE
 
